@@ -407,8 +407,11 @@ def ROCPlot(title, labels=None,*args):
         from pyroc import random_mixture_model, ROCData, plot_multiple_roc
         import pylab
     except ImportError:
-        print 'PyROC does not exist, skipping ROC demo. Install PyROC from : https://github.com/marcelcaraciolo/PyROC '
-        return    
+        try:
+            from pyroc import random_mixture_model, ROCData, plot_multiple_roc
+        except ImportError:
+            print 'PyROC does not exist, skipping ROC demo. Install PyROC from : https://github.com/marcelcaraciolo/PyROC '
+            return    
     if(len(args)==0):
         x = random_mixture_model()
         r1 = ROCData(x)
